@@ -176,6 +176,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Fujifilm FinePix S9100", { 12343,-4515,-1285,-7165,14899,2435,-1895,2496,8800 } },
     { "Fujifilm FinePix S9600", { 12343,-4515,-1285,-7165,14899,2435,-1895,2496,8800 } },
     { "Fujifilm FinePix S9600fd", { 12343,-4515,-1285,-7165,14899,2435,-1895,2496,8800 } }, // Copied from above
+    { "Fujifilm GFX 50R", { 11756,-4754,-874,-3056,11045,2305,-381,1457,6006 } },
     { "Fujifilm GFX 50S", { 11756,-4754,-874,-3056,11045,2305,-381,1457,6006 } },
     { "Fujifilm IS-1", { 21461,-10807,-1441,-2332,10599,1999,289,875,7703 } },
     { "Fujifilm FinePix IS Pro", { 12300,-5110,-1304,-9117,17143,1998,-1947,2448,8100 } },
@@ -242,6 +243,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Kodak DCS760C", { 16623,-6309,-1411,-4344,13923,323,2285,274,2926 } },
     { "Kodak DCS Pro SLR/n", { 5494,2393,-232,-6427,13850,2846,-1876,3997,5445 } },
     { "Kodak DCS Pro 14nx", { 5494,2393,-232,-6427,13850,2846,-1876,3997,5445 } },
+    { "Kodak DCS Pro 14N", { 7791,3128,-776,-8588,16458,2039,-2455,4006,6198 } },
     { "Kodak DCS Pro 14", { 7791,3128,-776,-8588,16458,2039,-2455,4006,6198 } },
     { "Kodak ProBack645", { 16414,-6060,-1470,-3555,13037,473,2545,122,4948 } },
     { "Kodak ProBack", { 21179,-8316,-2918,-915,11019,-165,3477,-180,4210 } },
@@ -551,7 +553,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Phase One H 20", { 1313,1855,-109,-6715,15908,808,-327,1840,6020 } }, /* DJC */
     { "Phase One H 25", { 2905,732,-237,-8134,16626,1476,-3038,4253,7517 } },
     { "Phase One P 2", { 2905,732,-237,-8134,16626,1476,-3038,4253,7517 } },
-    { "Phase One P 30", { 4516,-245,-37,-7020,14976,2173,-3206,4671,7087 } },
+    { "Phase One P30", { 4516,-245,-37,-7020,14976,2173,-3206,4671,7087 } },
     { "Phase One P 45", { 5053,-24,-117,-5684,14076,1702,-2619,4492,5849 } },
     { "Phase One P40", { 8035,435,-962,-6001,13872,2320,-1159,3065,5434 } },
     { "Phase One P65+", { 8035,435,-962,-6001,13872,2320,-1159,3065,5434 } },
@@ -593,6 +595,7 @@ static void dt_dcraw_adobe_coeff(const char *name, float cam_xyz[1][12])
     { "Sony DSC-HX99", { 13076,-5686,-1481,-4027,12851,1251,-167,725,4937 } },
     { "Sony DSC-R1", { 8512,-2641,-694,-8042,15670,2526,-1821,2117,7414 } },
     { "Sony DSC-V3", { 7511,-2571,-692,-7894,15088,3060,-948,1111,8128 } },
+    { "Sony DSC-RX100M6", { 7325,-2321,-596,-3494,11674,2055,-668,1562,5031 } },
     { "Sony DSC-RX100M5A", { 11176,-4700,-965,-4004,12184,2032,-763,1726,5876 } },
     { "Sony DSC-RX100M5", { 6596,-2079,-562,-4782,13016,1933,-970,1581,5181 } },
     { "Sony DSC-RX100M4", { 6596,-2079,-562,-4782,13016,1933,-970,1581,5181 } },
