@@ -2,7 +2,7 @@
     RawSpeed - RAW file decoder.
 
     Copyright (C) 2018 Stefan Löffler
-    Copyright (C) 2018 Roman Lebedev
+    Copyright (C) 2018-2019 Roman Lebedev
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -95,7 +95,7 @@ const std::array<RLV, table17.length> decompandedTable17 = []() {
 } // namespace
 
 #define PRECISION_MIN 8
-#define PRECISION_MAX 32
+#define PRECISION_MAX 16
 
 #define MARKER_BAND_END 1
 
@@ -635,6 +635,77 @@ void VC5Decompressor::parseLargeCodeblock(const ByteStream& bs) {
   mVC5.iSubband.reset();
 }
 
+void VC5Decompressor::prepareBandDecodingPlan() {
+  assert(allDecodeableBands.empty());
+  allDecodeableBands.reserve(numSubbandsTotal);
+  // All the high-pass bands for all wavelets,
+  // in this specific order of decreasing worksize.
+  for (int waveletLevel = 0; waveletLevel < numWaveletLevels; waveletLevel++) {
+    for (auto channelId = 0; channelId < numChannels; channelId++) {
+      for (int bandId = 1; bandId <= numHighPassBands; bandId++) {
+        auto& channel = channels[channelId];
+        auto& wavelet = channel.wavelets[waveletLevel];
+        auto* band = wavelet.bands[bandId].get();
+        auto* decodeableHighPassBand =
+            dynamic_cast<Wavelet::HighPassBand*>(band);
+        allDecodeableBands.emplace_back(decodeableHighPassBand, wavelet);
+      }
+    }
+  }
+  // The low-pass bands at the end. I'm guessing they should be fast to
+  // decode.
+  for (Channel& channel : channels) {
+    // Low-pass band of the smallest wavelet.
+    Wavelet& smallestWavelet = channel.wavelets.back();
+    auto* decodeableLowPassBand =
+        dynamic_cast<Wavelet::LowPassBand*>(smallestWavelet.bands[0].get());
+    allDecodeableBands.emplace_back(decodeableLowPassBand, smallestWavelet);
+  }
+  assert(allDecodeableBands.size() == numSubbandsTotal);
+}
+
+void VC5Decompressor::prepareBandReconstruction() {
+  assert(reconstructionSteps.empty());
+  reconstructionSteps.reserve(numLowPassBandsTotal);
+  // For every channel, recursively reconstruct the low-pass bands.
+  for (auto& channel : channels) {
+    // Reconstruct the intermediate lowpass bands.
+    for (int waveletLevel = numWaveletLevels - 1; waveletLevel > 0;
+         waveletLevel--) {
+      Wavelet* wavelet = &(channel.wavelets[waveletLevel]);
+      Wavelet& nextWavelet = channel.wavelets[waveletLevel - 1];
+
+      auto* band = dynamic_cast<Wavelet::ReconstructableBand*>(
+          nextWavelet.bands[0].get());
+      reconstructionSteps.emplace_back(wavelet, band);
+    }
+    // Finally, reconstruct the final lowpass band.
+    Wavelet* wavelet = &(channel.wavelets.front());
+    reconstructionSteps.emplace_back(wavelet, &(channel.band));
+  }
+  assert(reconstructionSteps.size() == numLowPassBandsTotal);
+}
+
+void VC5Decompressor::prepareDecodingPlan() {
+  prepareBandDecodingPlan();
+  prepareBandReconstruction();
+}
+
+void VC5Decompressor::decodeThread(bool* exceptionThrown) const noexcept {
+  // Decode all the existing bands. May fail.
+  decodeBands(exceptionThrown);
+
+  // Proceed only if decoding did not fail.
+  if (*exceptionThrown)
+    return;
+
+  // And now, reconstruct the low-pass bands.
+  reconstructLowpassBands();
+
+  // And finally!
+  combineFinalLowpassBands();
+}
+
 void VC5Decompressor::decode(unsigned int offsetX, unsigned int offsetY,
                              unsigned int width, unsigned int height) {
   if (offsetX || offsetY || mRaw->dim != iPoint2D(width, height))
@@ -642,109 +713,14 @@ void VC5Decompressor::decode(unsigned int offsetX, unsigned int offsetY,
 
   initVC5LogTable();
 
-  const std::vector<DecodeableBand> allDecodeableBands = [&]() {
-    std::vector<DecodeableBand> bands;
-    bands.reserve(numSubbandsTotal);
-    // All the high-pass bands for all wavelets,
-    // in this specific order of decreasing worksize.
-    for (int waveletLevel = 0; waveletLevel < numWaveletLevels;
-         waveletLevel++) {
-      for (auto channelId = 0; channelId < numChannels; channelId++) {
-        for (int bandId = 1; bandId <= numHighPassBands; bandId++) {
-          auto& channel = channels[channelId];
-          auto& wavelet = channel.wavelets[waveletLevel];
-          auto* band = wavelet.bands[bandId].get();
-          auto* decodeableHighPassBand =
-              dynamic_cast<Wavelet::HighPassBand*>(band);
-          bands.emplace_back(decodeableHighPassBand, wavelet);
-        }
-      }
-    }
-    // The low-pass bands at the end. I'm guessing they should be fast to
-    // decode.
-    for (Channel& channel : channels) {
-      // Low-pass band of the smallest wavelet.
-      Wavelet& smallestWavelet = channel.wavelets.back();
-      auto* decodeableLowPassBand =
-          dynamic_cast<Wavelet::LowPassBand*>(smallestWavelet.bands[0].get());
-      bands.emplace_back(decodeableLowPassBand, smallestWavelet);
-    }
-    assert(allDecodeableBands.size() == numSubbandsTotal);
-    return bands;
-  }();
+  prepareDecodingPlan();
 
-  const std::vector<ReconstructionStep> reconstructionSteps = [&]() {
-    std::vector<ReconstructionStep> steps;
-    steps.reserve(numLowPassBandsTotal);
-    // For every channel, recursively reconstruct the low-pass bands.
-    for (auto& channel : channels) {
-      // Reconstruct the intermediate lowpass bands.
-      for (int waveletLevel = numWaveletLevels - 1; waveletLevel > 0;
-           waveletLevel--) {
-        Wavelet* wavelet = &(channel.wavelets[waveletLevel]);
-        Wavelet& nextWavelet = channel.wavelets[waveletLevel - 1];
-
-        auto* band = dynamic_cast<Wavelet::ReconstructableBand*>(
-            nextWavelet.bands[0].get());
-        steps.emplace_back(wavelet, band);
-      }
-      // Finally, reconstruct the final lowpass band.
-      Wavelet* wavelet = &(channel.wavelets.front());
-      steps.emplace_back(wavelet, &(channel.band));
-    }
-    assert(steps.size() == numLowPassBandsTotal);
-    return steps;
-  }();
-
-#ifdef HAVE_OPENMP
   bool exceptionThrown = false;
+#ifdef HAVE_OPENMP
 #pragma omp parallel default(none) shared(exceptionThrown)                     \
     num_threads(rawspeed_get_number_of_processor_cores())
-  {
 #endif
-#ifdef HAVE_OPENMP
-#pragma omp for schedule(dynamic, 1)
-#endif
-    for (auto decodeableBand = allDecodeableBands.begin();
-         decodeableBand < allDecodeableBands.end(); ++decodeableBand) {
-      try {
-        decodeableBand->band->decode(decodeableBand->wavelet);
-      } catch (RawspeedException& err) {
-        // Propagate the exception out of OpenMP magic.
-        mRaw->setError(err.what());
-#ifdef HAVE_OPENMP
-#pragma omp atomic write
-        exceptionThrown = true;
-#pragma omp cancel for
-#else
-        throw;
-#endif
-      }
-    }
-
-#ifdef HAVE_OPENMP
-#pragma omp cancel parallel if (exceptionThrown)
-
-    // Parallel region termination is usually disabled by default,
-    // thus we can't just rely on it. Proceed only if decoding did not fail.
-    if (!exceptionThrown) {
-#endif
-      // And now, reconstruct the low-pass bands.
-      for (const ReconstructionStep& step : reconstructionSteps) {
-        step.band.decode(step.wavelet);
-
-#ifdef HAVE_OPENMP
-#pragma omp single nowait
-#endif
-        step.wavelet.clear(); // we no longer need it.
-      }
-
-      // And finally!
-      combineFinalLowpassBands();
-
-#ifdef HAVE_OPENMP
-    }
-  }
+  decodeThread(&exceptionThrown);
 
   std::string firstErr;
   if (mRaw->isTooManyErrors(1, &firstErr)) {
@@ -754,7 +730,39 @@ void VC5Decompressor::decode(unsigned int offsetX, unsigned int offsetY,
   } else {
     assert(!exceptionThrown);
   }
+}
+
+void VC5Decompressor::decodeBands(bool* exceptionThrown) const noexcept {
+#ifdef HAVE_OPENMP
+#pragma omp for schedule(dynamic, 1)
 #endif
+  for (auto decodeableBand = allDecodeableBands.begin();
+       decodeableBand < allDecodeableBands.end(); ++decodeableBand) {
+    try {
+      decodeableBand->band->decode(decodeableBand->wavelet);
+    } catch (RawspeedException& err) {
+      // Propagate the exception out of OpenMP magic.
+      mRaw->setError(err.what());
+#ifdef HAVE_OPENMP
+#pragma omp atomic write
+#endif
+      *exceptionThrown = true;
+#ifdef HAVE_OPENMP
+#pragma omp cancel for
+#endif
+    }
+  }
+}
+
+void VC5Decompressor::reconstructLowpassBands() const noexcept {
+  for (const ReconstructionStep& step : reconstructionSteps) {
+    step.band.decode(step.wavelet);
+
+#ifdef HAVE_OPENMP
+#pragma omp single nowait
+#endif
+    step.wavelet.clear(); // we no longer need it.
+  }
 }
 
 void VC5Decompressor::combineFinalLowpassBands() const noexcept {
