@@ -53,7 +53,8 @@ typedef struct dt_gui_scrollbars_t
     gboolean dragging;
 } dt_gui_scrollbars_t;
 
-typedef enum dt_gui_color_t {
+typedef enum dt_gui_color_t
+{
   DT_GUI_COLOR_BG = 0,
   DT_GUI_COLOR_DARKROOM_BG,
   DT_GUI_COLOR_DARKROOM_PREVIEW_BG,
@@ -61,6 +62,18 @@ typedef enum dt_gui_color_t {
   DT_GUI_COLOR_LIGHTTABLE_PREVIEW_BG,
   DT_GUI_COLOR_BRUSH_CURSOR,
   DT_GUI_COLOR_BRUSH_TRACE,
+  DT_GUI_COLOR_THUMBNAIL_BG,
+  DT_GUI_COLOR_THUMBNAIL_SELECTED_BG,
+  DT_GUI_COLOR_THUMBNAIL_HOVER_BG,
+  DT_GUI_COLOR_THUMBNAIL_OUTLINE,
+  DT_GUI_COLOR_THUMBNAIL_SELECTED_OUTLINE,
+  DT_GUI_COLOR_THUMBNAIL_HOVER_OUTLINE,
+  DT_GUI_COLOR_THUMBNAIL_FONT,
+  DT_GUI_COLOR_THUMBNAIL_SELECTED_FONT,
+  DT_GUI_COLOR_THUMBNAIL_HOVER_FONT,
+  DT_GUI_COLOR_THUMBNAIL_BORDER,
+  DT_GUI_COLOR_THUMBNAIL_SELECTED_BORDER,
+  DT_GUI_COLOR_FILMSTRIP_BG,
   DT_GUI_COLOR_LAST
 } dt_gui_color_t;
 
