@@ -290,12 +290,31 @@ static void _gui_styles_dialog_run(gboolean edit, const char *name, int imgid)
 #endif
 
   GtkContainer *content_area = GTK_CONTAINER(gtk_dialog_get_content_area(GTK_DIALOG(dialog)));
+
+  // label box
   GtkBox *box = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, DT_PIXEL_APPLY_DPI(5)));
   gtk_widget_set_margin_start(GTK_WIDGET(box), DT_PIXEL_APPLY_DPI(10));
   gtk_widget_set_margin_end(GTK_WIDGET(box), DT_PIXEL_APPLY_DPI(10));
   gtk_widget_set_margin_top(GTK_WIDGET(box), DT_PIXEL_APPLY_DPI(10));
   gtk_widget_set_margin_bottom(GTK_WIDGET(box), DT_PIXEL_APPLY_DPI(10));
-  gtk_container_add(content_area, GTK_WIDGET(box));
+
+  GtkWidget *scroll = gtk_scrolled_window_new(NULL, NULL);
+  gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(scroll), GTK_POLICY_NEVER, GTK_POLICY_AUTOMATIC);
+  gtk_scrolled_window_set_min_content_height(GTK_SCROLLED_WINDOW(scroll), DT_PIXEL_APPLY_DPI(300));
+//  only available in 3.22, and not making the expected job anyway
+//  gtk_scrolled_window_set_max_content_height(GTK_SCROLLED_WINDOW(scroll), DT_PIXEL_APPLY_DPI(700));
+//  gtk_scrolled_window_set_propagate_natural_height(GTK_SCROLLED_WINDOW(scroll), TRUE);
+  gtk_widget_set_margin_start(scroll, DT_PIXEL_APPLY_DPI(5));
+  gtk_widget_set_margin_end(scroll, DT_PIXEL_APPLY_DPI(5));
+  gtk_widget_set_margin_top(scroll, DT_PIXEL_APPLY_DPI(5));
+  gtk_widget_set_margin_bottom(scroll, DT_PIXEL_APPLY_DPI(5));
+
+  // box in scrollwindow containing the two possible trees
+  GtkBox *sbox = GTK_BOX(gtk_box_new(GTK_ORIENTATION_VERTICAL, DT_PIXEL_APPLY_DPI(5)));
+
+  gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(box), FALSE, FALSE, 0);
+  gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(scroll), TRUE, TRUE, 0);
+  gtk_container_add(GTK_CONTAINER(scroll), GTK_WIDGET(sbox));
 
   sd->name = gtk_entry_new();
   gtk_widget_set_tooltip_text(sd->name, _("enter a name for the new style"));
@@ -457,11 +476,11 @@ static void _gui_styles_dialog_run(gboolean edit, const char *name, int imgid)
     }
   }
 
-  if(has_item) gtk_box_pack_start(box, GTK_WIDGET(sd->items), TRUE, TRUE, 0);
+  if(has_item) gtk_box_pack_start(sbox, GTK_WIDGET(sd->items), TRUE, TRUE, 0);
 
-  if(has_new_item) gtk_box_pack_start(box, GTK_WIDGET(sd->items_new), TRUE, TRUE, 0);
+  if(has_new_item) gtk_box_pack_start(sbox, GTK_WIDGET(sd->items_new), TRUE, TRUE, 0);
 
-  if(edit) gtk_box_pack_start(box, GTK_WIDGET(sd->duplicate), FALSE, FALSE, 0);
+  if(edit) gtk_box_pack_start(GTK_BOX(content_area), GTK_WIDGET(sd->duplicate), FALSE, FALSE, 0);
 
   g_object_unref(liststore);
   g_object_unref(liststore_new);
