@@ -33,6 +33,10 @@
 
 DT_MODULE_INTROSPECTION(1, dt_iop_rotatepixels_params_t)
 
+typedef struct dt_iop_rotatepixels_gui_data_t
+{
+} dt_iop_rotatepixels_gui_data_t;
+
 typedef struct dt_iop_rotatepixels_params_t
 {
   uint32_t rx, ry;
@@ -45,6 +49,8 @@ typedef struct dt_iop_rotatepixels_data_t
   float m[4];      // rotation matrix
 } dt_iop_rotatepixels_data_t;
 
+dt_iop_rotatepixels_gui_data_t dummy;
+
 static void mul_mat_vec_2(const float *m, const float *p, float *o)
 {
   o[0] = p[0] * m[0] + p[1] * m[1];
@@ -342,7 +348,7 @@ void init(dt_iop_module_t *self)
   self->params = calloc(1, sizeof(dt_iop_rotatepixels_params_t));
   self->default_params = calloc(1, sizeof(dt_iop_rotatepixels_params_t));
   self->params_size = sizeof(dt_iop_rotatepixels_params_t);
-  self->gui_data = NULL;
+  self->gui_data = &dummy;
   self->priority = 242; // module order created by iop_dependencies.py, do not edit!
 }
 
@@ -361,7 +367,6 @@ void gui_init(dt_iop_module_t *self)
 
 void gui_cleanup(dt_iop_module_t *self)
 {
-  free(self->gui_data);
   self->gui_data = NULL;
 }
 
