@@ -624,6 +624,17 @@ static gboolean _lib_filmstrip_button_release_callback(GtkWidget *w, GdkEventBut
   return result;
 }
 
+static gboolean _expose_again(gpointer user_data)
+{
+  // unfortunately there might have been images without thumbnails during expose.
+  // this can have multiple reasons: not loaded yet (we'll receive a signal when done)
+  // or still locked for writing.. we won't be notified when this changes.
+  // so we just track whether there were missing images and expose again.
+  if(darktable.view_manager->proxy.filmstrip.module)
+    gtk_widget_queue_draw(darktable.view_manager->proxy.filmstrip.module->widget);
+  return FALSE; // don't call again
+}
+
 static gboolean _lib_filmstrip_draw_callback(GtkWidget *widget, cairo_t *cr, gpointer user_data)
 {
   dt_lib_module_t *self = (dt_lib_module_t *)user_data;
@@ -643,7 +654,7 @@ static gboolean _lib_filmstrip_draw_callback(GtkWidget *widget, cairo_t *cr, gpo
   strip->image_over = DT_VIEW_DESERT;
 
   /* fill background */
-  cairo_set_source_rgb(cr, .2, .2, .2);
+  dt_gui_gtk_set_source_rgb(cr, DT_GUI_COLOR_FILMSTRIP_BG);
   cairo_paint(cr);
 
   int offset = strip->offset;
@@ -686,6 +697,8 @@ static gboolean _lib_filmstrip_draw_callback(GtkWidget *widget, cairo_t *cr, gpo
 
   cairo_save(cr);
   cairo_translate(cr, empty_edge, 0.0f);
+  int missing = 0;
+
   for(int col = 0; col < max_cols; col++)
   {
     if(col < col_start)
@@ -713,7 +726,7 @@ static gboolean _lib_filmstrip_draw_callback(GtkWidget *widget, cairo_t *cr, gpo
       // getting it from the matrix ...
       cairo_matrix_t m;
       cairo_get_matrix(cr, &m);
-      dt_view_image_expose(&(strip->image_over), id, cr, wd, ht, max_cols, img_pointerx, img_pointery, FALSE, FALSE);
+      missing += dt_view_image_expose(&(strip->image_over), id, cr, wd, ht, max_cols, img_pointerx, img_pointery, FALSE, FALSE);
       cairo_restore(cr);
     }
     else if(step_res == SQLITE_DONE)
@@ -751,6 +764,8 @@ failure:
   if(darktable.unmuted & DT_DEBUG_CACHE) dt_mipmap_cache_print(darktable.mipmap_cache);
 #endif
 
+  if(missing) g_timeout_add(250, _expose_again, widget);
+
   return TRUE;
 }
 
